#[allow(unused)]
use log::info;
use serde::{Deserialize, Serialize};
use crate::{server::LspServer, utils::command::is_command_valid};
use super::{AbstractLinterConfiguration, LinterStatus};
use ropey::Rope;
use tower_lsp::lsp_types::{Diagnostic, Url};

#[derive(Debug, Serialize, Deserialize)]
pub struct ModelsimConfiguration {
    pub language_id: String,
    pub linter: ModelsimLinter
}


#[derive(Debug, Serialize, Deserialize)]
pub struct ModelsimLinter {
    pub name: String,
    pub exe_name: String,
    /// 目前是否启动
    pub enabled: bool,
    pub path: String,
    pub args: Vec<String>,
}


impl ModelsimLinter {
    fn new(invoker: &str, args: Vec<String>) -> Self {
        Self {
            name: "modelsim".to_string(),
            exe_name: invoker.to_string(),
            enabled: false,
            path: invoker.to_string(),
            args,
        }
    }
}


impl AbstractLinterConfiguration for ModelsimConfiguration {
    fn new(language_id: &str, invoker: &str, args: Vec<String>) -> Self {
        ModelsimConfiguration {
            language_id: language_id.to_string(),
            linter: ModelsimLinter::new(invoker, args)
        }
    }
    
    fn provide_diagnostics(
        &self,
        uri: &Url,
        rope: &Rope,
        server: &LspServer
    ) -> Option<Vec<Diagnostic>> {
        let mut diagnostics = Vec::<Diagnostic>::new();

        Some(diagnostics)
    }

    fn get_linter_path(&self) -> &str {
        &self.linter.path
    }

    fn get_exe_name(&self) -> String {
        if std::env::consts::OS == "windows" {
            format!("{}.exe", self.linter.exe_name)
        } else {
            self.linter.exe_name.to_string()
        }
    }
}